/**
 * A class that can execute selector-based DOM queries, with supporting for
 * intermediate indexing.
 */
export default class DOMQuery {
    readonly root: Element | null;
    readonly selector: string;
    /**
     * @param root the root element from which to query
     * @param selector the selector to query
     */
    constructor(root: Element | null, selector: string);
    /**
     * Query the first matching element
     */
    query(): Element | null;
    /**
     * Query all matching elements
     */
    queryAll(): Element[];
    /**
     * Create a child {@link DOMQuery} from a selector and an optional index.
     * {@link DOMQuery} objects created using this method are not guaranteed to be
     * lazy -- if an index is specified, the query will be executed immediately.
     *
     * @param selector selector to query
     * @param index target index of the {@link Element} in the query results, or
     * null if this isn't an index query
     */
    createChild(selector: string, index: number | null): DOMQuery;
}
